- As the daemons are running when the restore is done then if the daemons are 
not
   restarted the running daemon stays with the previous config and not with the 
restored
   version.

Tested-by: Adolf Belka <[email protected]>
Signed-off-by: Adolf Belka <[email protected]>
---
 config/backup/backup.pl | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/config/backup/backup.pl b/config/backup/backup.pl
index c9bc14355..e79f510c6 100644
--- a/config/backup/backup.pl
+++ b/config/backup/backup.pl
@@ -349,8 +349,10 @@ restore_backup() {
                rm /var/log/pakfire.log
        fi
 
        # Update the OpenVPN configuration
        sudo -u nobody /srv/web/ipfire/cgi-bin/ovpnmain.cgi
+       /etc/init.d/openvpn-n2n restart
+       /etc/init.d/openvpn-rw restart
 
        return 0
 }
@@ -349,8 +349,10 @@ restore_backup() {
        fi
 
-       # Update the OpenVPN configuration
+       # Update the OpenVPN configuration and restart the openvpn daemons
        sudo -u nobody /srv/web/ipfire/cgi-bin/ovpnmain.cgi
-- 
2.50.1


Reply via email to